@@ -138,7 +138,7 @@ void regress_test_cairo_surface_none_in (cairo_surface_t *surface);
 void regress_test_cairo_surface_full_out (cairo_surface_t **surface);
 
 /* versioning (deprecated, since, stability) */
-void regress_test_versioning ();
+void regress_test_versioning (void);
 
 GVariant *regress_test_gvariant_i (void);
 GVariant *regress_test_gvariant_s (void);
@@ -259,6 +259,11 @@ GQuark regress_atest_error_quark (void);
 #define REGRESS_DOUBLE_CONSTANT 44.22
 #define REGRESS_STRING_CONSTANT "Some String"
 #define REGRESS_Mixed_Case_Constant 4423
+#define REGRESS_G_GINT64_CONSTANT (G_GINT64_CONSTANT (1000))
+#define REGRESS_GUINT64_CONSTANT ((guint64) -1)
+
+typedef guint64 RegressTestTypeGUInt64;
+#define REGRESS_GUINT64_CONSTANTA ((RegressTestTypeGUInt64) -1)
 
 /* structures */
 typedef struct _RegressTestStructA RegressTestStructA;
